django_premailer.tests package
==============================

Subpackages
-----------

.. toctree::

    django_premailer.tests.testapp

Submodules
----------

django_premailer.tests.test_templatetags module
-----------------------------------------------

.. automodule:: django_premailer.tests.test_templatetags
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_premailer.tests
    :members:
    :undoc-members:
    :show-inheritance:
